# comfyui_frontend pypi package

This is the pypi package structure for the comfyui frontend.

During build process, the compiled assets are copied into the `comfyui_frontend/static` directory.

The package can be installed with the following command:

```bash
pip install comfyui_frontend
```
